pub enum ContentOrigin {
CargoManifestDescription(PathBuf),
CommonMarkFile(PathBuf),
RustDocTest(PathBuf, Span),
RustSourceFile(PathBuf),
TestEntityRust,
TestEntityCommonMark,
}Expand description
Definition of the source of a checkable chunk
Variants
CargoManifestDescription(PathBuf)
A Cargo.toml manifest that contains a description field.
CommonMarkFile(PathBuf)
A common mark file at given path.
RustDocTest(PathBuf, Span)
A rustdoc comment, part of file reference by path in span.
RustSourceFile(PathBuf)
Full rust source file.
TestEntityRust
A test entity for a rust file, with no meaning outside of test.
TestEntityCommonMark
A test entity for a cmark file, with no meaning outside of test.
Implementations
Sourceimpl ContentOrigin
impl ContentOrigin