Suggestion

Struct Suggestion 

pub struct Suggestion<'s> {
    pub detector: Detector,
    pub origin: ContentOrigin,
    pub chunk: &'s CheckableChunk,
    pub span: Span,
    pub range: Range,
    pub replacements: Vec<String>,
    pub description: Option<String>,
}
A suggestion for certain offending span.

Fields

detector: Detector

Which checker suggested the change.

origin: ContentOrigin

Reference to the file location the span and literal relate to.

chunk: &'s CheckableChunk

The suggestion is relative to a specific chunk.

span: Span

The span (absolute!) within the file or chunk (depends on origin).

range: Range

Range relative to the chunk the current suggestion is located.

replacements: Vec<String>

Fix suggestions, might be words or the full sentence together with leading whitespaces for some CommentVariants.

description: Option<String>

Descriptive reason for the suggestion.

Implementations

Source

impl<'s> Suggestion<'s>

pub fn is_overlapped(&self, other: &Self) -> bool

Determine if there is overlap.